@@ -5,7 +5,7 @@ package A1z::HTML5::Template;
 # ABSTRACT: Fast/easy HTML5 apps/pages in Perl
 
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 
 
@@ -100,6 +100,8 @@ sub timestable
 }
 # end timestable 
 
+
+
 # begin header 
 sub header 
 {
@@ -145,6 +147,8 @@ sub header
 } 
 # end header 
 
+
+
 # begin start html 01
 sub start_html  
 { 
@@ -183,6 +187,9 @@ sub start_html
 } 
 # end start_html 
 
+
+
+
 sub body_js_css 
 {
 	my $self = shift;
@@ -196,54 +203,58 @@ sub body_js_css
 	
 	my $out; 
 	
-	$out .= qq{<!--jquery-->
-<script src="https://code.jquery.com/jquery-1.12.4.min.js"></script>
-<!--bootstrap/jQueryUI-->
-<script src="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.0/js/bootstrap.min.js"></script>
-<script src="https://code.jquery.com/ui/1.11.4/jquery-ui.min.js"></script>
+	$out .= qq^
+		<!--jquery-->
+		<script src="https://code.jquery.com/jquery-1.12.4.min.js"></script>
+		<!--bootstrap/jQueryUI-->
+		<script src="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.0/js/bootstrap.min.js"></script>
+		<script src="https://code.jquery.com/ui/1.11.4/jquery-ui.min.js"></script>
 
-<!-- IE10 viewport hack for Surface/desktop Windows 8 bug -->
-<script type="text/javascript" src="/jquery/bootstrap/fixed-top/ie10-viewport-bug-workaround.js"></script>
-<script type="text/javascript">
-// for tabs 
-\$(function() {
-    var tabs = \$( "#tabs" ).tabs();
-    tabs.find( ".ui-tabs-nav" ).sortable({
-      axis: "x",
-      stop: function() {
-        tabs.tabs( "refresh" );
-      }
-    });
-  }); 
-  
-// dialog 
-\$(function() {
-    \$( "#dialog" ).dialog({
-      autoOpen: false,
-      show: {
-        effect: "blind",
-        duration: 1000
-      },
-      hide: {
-        effect: "explode",
-        duration: 1000
-      }
-    });
- 
-    \$( "#opener" ).click(function() {
-      \$( "#dialog" ).dialog( "open" );
-    });
-  });
-  
-\$('#menu').menu(); 
-\$('#accordion').accordion(); 
-\$('#accordion1').accordion(); 
-\$('#accordion2').accordion(); 
-\$('#accordion3').accordion(); 
-\$('#tabs').tabs(); 
-//\$('#dialog').dialog(); // no need, is taken care by the animation dialog above.  enabling this will make the dialog appear on load instead of on click of a/the link
-</script>
-}; 
+		<!-- IE10 viewport hack for Surface/desktop Windows 8 bug -->
+		<script type="text/javascript" src="/jquery/bootstrap/fixed-top/ie10-viewport-bug-workaround.js"></script>
+
+		<script type="text/javascript">
+		
+		// for tabs 
+		\$( function() {
+			var tabs = \$("#tabs").tabs();
+			tabs.find( ".ui-tabs-nav" ).sortable({
+				axis: "x",
+				stop: function() { tabs.tabs( "refresh" ); }
+			});
+		}); 
+		  
+		// dialog 
+		\$( function() {
+			\$( "#dialog" ).dialog({
+			  autoOpen: false,
+			  show: {
+				effect: "blind",
+				duration: 1000
+			  },
+			  hide: {
+				effect: "explode",
+				duration: 1000
+			  }
+			});
+		 
+			\$( "#opener" ).click(function() {
+			  \$( "#dialog" ).dialog( "open" );
+			});
+		});
+		  
+		\$('#menu').menu(); 
+		\$('#accordion').accordion(); 
+		\$('#accordion1').accordion(); 
+		\$('#accordion2').accordion(); 
+		\$('#accordion3').accordion(); 
+		\$('#tabs').tabs(); 
+		
+		</script>
+	
+	^; 
+	
+	
 	if ( $args ) 
 	{
 		
@@ -269,11 +280,11 @@ sub body_js_css
 				}
 			}
 			
-			return qq{<!--216 jQ-->$return}; 	#
+			return qq{$return}; 	#
 		}
 		else 
 		{
-			return qq{<!--223 noArgs-->$out}; 
+			return qq{$out}; 
 		}
 		
 	}
@@ -282,7 +293,10 @@ sub body_js_css
 		return qq{<!--229 noParams-->$out}; 	# 
 	} 
 	
-} 
+}
+
+
+
 
 
 # start end_html 
@@ -310,6 +324,9 @@ sub end_html
 } 
 # end end_html
 
+
+
+
 # start head title 02 
 sub head_title
 {
@@ -345,6 +362,9 @@ sub head_title
 } 
 # end head title 
 
+
+
+
 # begin head meta 03
 sub head_meta
 {
@@ -400,6 +420,9 @@ sub head_meta
 } 
 # end head meta 03 
 
+
+
+
 # begin body top nav bar
 sub body_topnavbar
 {
@@ -428,6 +451,9 @@ sub body_topnavbar
 } 
 # end body top nav bar
 
+
+
+
 sub head_js_css
 {
 	my $self = shift;
@@ -441,17 +467,20 @@ sub head_js_css
 	
 	my $out; 
 	
-	$out .= qq{<!-- Bootstrap/jqueryUI -->
+	$out .= qq{
+	
+	<!-- Bootstrap/jqueryUI -->
 
-<link href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.0/css/bootstrap.min.css" rel="stylesheet" type="text/css">
-<link href="https://secure.bislinks.com/jquery/bootstrap/fixed-top/navbar-fixed-top.css" rel="stylesheet">
-<link href="https://code.jquery.com/ui/1.12.1/themes/smoothness/jquery-ui.css" rel="stylesheet">
+	<link href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.0/css/bootstrap.min.css" rel="stylesheet" type="text/css">
+	<link href="https://secure.bislinks.com/jquery/bootstrap/fixed-top/navbar-fixed-top.css" rel="stylesheet">
+	<link href="https://code.jquery.com/ui/1.12.1/themes/smoothness/jquery-ui.css" rel="stylesheet">
 
-<!-- HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries -->
-<!--[if lt IE 9]>
-<script src="https://oss.maxcdn.com/html5shiv/3.7.2/html5shiv.min.js"></script>
-<script src="https://oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>
-<![endif]-->
+	<!--HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries-->
+
+	<!--[if lt IE 9]>
+	<script src="https://oss.maxcdn.com/html5shiv/3.7.2/html5shiv.min.js"></script>
+	<script src="https://oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>
+	<![endif]-->
 
 }; 
 	
@@ -462,7 +491,7 @@ sub head_js_css
 		{
 			my $return;
 			
-			for (@keys ) 
+			for (@keys) 
 			{
 				chomp;
 				if ($_ =~ /.js$/)
@@ -496,6 +525,9 @@ sub head_js_css
 } 
 # end head js css
 
+
+
+
 # begin end head
 sub end_head 
 { 
@@ -531,6 +563,7 @@ sub end_head
 # end end head 
 
 
+
 # begin begin body 
 sub begin_body 
 { 
@@ -570,9 +603,6 @@ sub begin_body
 # begin accordion or rather file content.  Need to change name of this method
 sub body_accordion 
 {
-
-
-
 	my $self = shift;
 	
 	my $key = "@_"; 
@@ -617,6 +647,9 @@ sub body_accordion
 } 
 # end accordion
 
+
+
+
 sub body_article 
 {  
 	my $self = shift;
@@ -647,6 +680,9 @@ sub body_article
 	}
 }
 
+
+
+
 # begin begin body 
 sub end_body 
 { 
@@ -681,6 +717,9 @@ sub end_body
 } 
 # end end body
 
+
+
+
 # begin content folder to select form 
 sub body_form 
 {
@@ -691,7 +730,7 @@ sub body_form
 	my @keys;  
 	if (@_) { @keys = @_; } 
 	
-	my ($vars, $vals) = ''; 
+	my ($vars, $vals) = (''); 
 	for (@keys) 
 	{
 		$vars = $_ if ($_ =~ /^vars/); 
@@ -721,11 +760,12 @@ sub body_form
 	{
 		# get the params for the form 
 		my ($sel_key, $sel_name, $sel_default, $folder_or_file) = split(/\,/, $form_vars[3], 4); 
-		$select .= qq{<label for"$sel_name">$sel_default</label>
-<div class="form-group"><!--begin select-->
-<select name="$sel_name">
-	<option selected value="$sel_default">$sel_default</option>
-};
+		$select .= qq{
+			<label for"$sel_name">$sel_default</label>
+			<div class="form-group"><!--begin select-->
+			<select name="$sel_name">
+			<option selected value="$sel_default">$sel_default</option>
+		};
 		
 		#now open file/folder to fill "options" 
 		if ( -f $folder_or_file ) 
@@ -749,7 +789,7 @@ sub body_form
 				next if $file =~ /^(\.|\.\.)/; 
 				# do not add hidden files to the options list
 				next if $file =~ /^\./; 
-				#$select .= '  ' x 8 . qq{<option value="$file">$file</option>\n~ if $file; 	# ' ' x 8 = 8 spaces 
+				#$select .= '  ' x 8 . qq{<option value="$file">$file</option>\n} if $file; 	# ' ' x 8 = 8 spaces 
 				
 				# get the size of th file 
 				my $size = -s "$folder_or_file/$file"; 
@@ -757,13 +797,13 @@ sub body_form
 					$size /= 1024; 
 					$size /= 1024;
 					$size = sprintf "%.2f", $size; 
-				$select .= qq{\t<option value="$file">$file [$size mb]</option>\n~ if $file; 	# ' ' x 9 #= spaces
+				$select .= qq{\t<option value="$file">$file [$size mb]</option>\n} if $file; 	# ' ' x 9 #= spaces
 			}
 		}
 
-$select .= qq{</select>
-</div><!--end select-->
-}; 
+		$select .= qq{
+			</select> </div> 
+		}; 
 	}
 	else 
 	{
@@ -777,19 +817,19 @@ $select .= qq{</select>
 		# add hidden fields/values # from $form_vars[4] 
 		for (@hidden)
 		{
-			my ($name, $value) = split(/---/, $_, 2) if $_; 
-			$out .= qq{<input type="hidden" name="$name" value="$value"/>\n~ if $_; 
+			my ($name, $value) = split(/\-\-\-/, $_, 2) if $_; 
+			$out .= qq{<input type="hidden" name="$name" value="$value"/>\n} if $_; 
 		}
 		# add select 
 		$out .= qq{$select};  
 	$out .= qq{\n<button type="submit" class="btn btn-default">Submit</button>\n</form>\n\n}; 
 	
 	return qq{$out}; 
-	
-	
 }
 
-# 
+# end body_form 
+
+
 
 sub defaults_begin
 {
@@ -812,6 +852,8 @@ sub defaults_begin
 		return $out; 
 }
 
+
+
 sub defaults_end 
 {
 	my $self = shift; 
@@ -829,60 +871,64 @@ sub defaults_end
 
 
 
-# Begin Fri Mar 13 00:15:20 2015
-
-
 # HTML 
-my %HTML = (
-	-defaultjquery => qq{<script src="https://code.jquery.com/ui/1.11.4/jquery-ui.min.js"></script>
-<!--bootstrap/jQueryUI-->
-<script type="text/javascript" src="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.0/js/bootstrap.min.js"></script>
-<script type="text/javascript" src="https://code.jquery.com/ui/1.11.4/themes/ui-lightness/jquery-ui.css"></script>
-<!-- IE10 viewport hack for Surface/desktop Windows 8 bug -->
-<script type="text/javascript" src="/jquery/bootstrap/fixed-top/ie10-viewport-bug-workaround.js"></script>
-<script type="text/javascript">
-// for tabs 
-\$(function() {
-    var tabs = \$( "#tabs" ).tabs();
-    tabs.find( ".ui-tabs-nav" ).sortable({
-      axis: "x",
-      stop: function() {
-        tabs.tabs( "refresh" );
-      }
-    });
-  }); 
-  
-// dialog 
-\$(function() {
-    \$( "#dialog" ).dialog({
-      autoOpen: false,
-      show: {
-        effect: "blind",
-        duration: 1000
-      },
-      hide: {
-        effect: "explode",
-        duration: 1000
-      }
-    });
- 
-    \$( "#opener" ).click(function() {
-      \$( "#dialog" ).dialog( "open" );
-    });
-  });
-  
-\$('#menu').menu(); 
-\$('#accordion').accordion(); 
-\$('#accordion1').accordion(); 
-\$('#accordion2').accordion(); 
-\$('#accordion3').accordion(); 
-\$('accordion617').accordion();
-\$('#tabs').tabs(); 
-</script>
-},
-	 
+my %HTML;
+
+%HTML = (
+	-defaultjquery => qq{
+		<script src="https://code.jquery.com/ui/1.11.4/jquery-ui.min.js"></script>
+		<!--bootstrap/jQueryUI-->
+		<script type="text/javascript" src="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.0/js/bootstrap.min.js"></script>
+		<script type="text/javascript" src="https://code.jquery.com/ui/1.11.4/themes/ui-lightness/jquery-ui.css"></script>
+		<!-- IE10 viewport hack for Surface/desktop Windows 8 bug -->
+		<script type="text/javascript" src="/jquery/bootstrap/fixed-top/ie10-viewport-bug-workaround.js"></script>
+		<script type="text/javascript">
+		
+		// for tabs 
+		\$( function() {
+			var tabs = \$( "#tabs" ).tabs();
+			
+			tabs.find( ".ui-tabs-nav" ).sortable({
+				axis: "x",
+				stop: function() { tabs.tabs( "refresh" ); }
+			});
+		}); 
+		  
+		// dialog 
+		\$(function() {
+			\$( "#dialog" ).dialog({
+			  autoOpen: false,
+			  show: {
+				effect: "blind",
+				duration: 1000
+			  },
+			  hide: {
+				effect: "explode",
+				duration: 1000
+			  }
+			});
+		 
+			\$( "#opener" ).click(function() {
+			  \$( "#dialog" ).dialog( "open" );
+			});
+		});
+		  
+			\$('#menu').menu(); 
+			\$('#accordion').accordion(); 
+			\$('#accordion1').accordion(); 
+			\$('#accordion2').accordion(); 
+			\$('#accordion3').accordion(); 
+			\$('accordion617').accordion();
+			\$('#tabs').tabs(); 
+		
+		</script>
+	},
+	
+	-default_LastItem => qq{},
+	
 );
 
+
 sub html_bootstrap_css   
 {
 	return qq{<!-- Bootstrap/jqueryUI -->
@@ -1054,7 +1100,7 @@ if ($in{-cssLinks} )
 		{
 			if ($_ =~ /\.css$/) 
 			{
-				$css .= qq{<link type="text/css" rel="stylesheet" href="$_">\n~ ; 
+				$css .= qq{<link type="text/css" rel="stylesheet" href="$_">\n} ; 
 			}
 			else 
 			{
@@ -1345,7 +1391,7 @@ sub open_file
 					$h1 =~ s!^--!!g;
 				} 
 				
-				$out .= qq{\t<h3>$h1</h3>\n\t<div>$div</div>\n~ if $line; 
+				$out .= qq{\t<h3>$h1</h3>\n\t<div>$div</div>\n} if $line; 
 			} 
 			elsif ($output_format eq 'menu') 
 			{
@@ -1460,7 +1506,7 @@ sub open_file
 			
 			($h1, $div) = split(/\t+/, $line, 2) if $line; 
 			
-			$out .= qq{\t<h3>$h1</h3>\n\t<div>$div</div>\n~ if $line; 
+			$out .= qq{\t<h3>$h1</h3>\n\t<div>$div</div>\n} if $line; 
 		} 
 		$out .= qq{\t<h3>Powered by</h3>\n\t<div>Package HTML5</div>\n}; 
 		
@@ -1670,7 +1716,7 @@ A1z::HTML5::Template - Fast/easy HTML5 apps/pages in Perl
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -1729,12 +1775,11 @@ version 0.08
 
 =head1 VERSION
 
-	Version 0.08
+	Version 0.09
 
 =head1 METHODS
 
-header start_html head_title head_meta head_js_css end_head begin_body body_js_css body_topnavbar 
-body_accordion end_body end_html 
+	header start_html head_title head_meta head_js_css end_head begin_body body_js_css body_topnavbar body_accordion end_body end_html 
 
 =head2 new
 
@@ -1744,16 +1789,143 @@ body_accordion end_body end_html
 =head2 math1
 
 	$h->math1(num1, num2);
+	
+	$h->body_article( header => "Math", content => $h->math1(num1, num2) );
 
-=head1 Times Table
+=head2 timestable
 
 	$h->timestable("Number");
 
-=head1 Usage
+=head2 header
+
+	Provides HTML Content-Header 
+	
+	$h->header("");
+
+=head2 start_html
+
+	Provides doctype html
+	
+	$h->start_html();
+	
+	$h->start_html('utf8');
+
+=head2 body_js_css
+
+	Add/include javascript and css files just above </body> section 
+	
+	Typically, CSS files should/are not be used here. 
+	
+	Default behavior: 
+	
+		$h->body_js_css();
+		
+		Includes 
+			jquery 1.12.4, jquery ui 1.11.4, bootstrap 3.3.0, 
+			javascript for #dialog function, #menu, #accordion, #tabs 
+	
+	Add your own .js file: 
+		
+		use $h->body_js_css("/path/to/js/file.js");
+		
+	You can use both to include default .js files and your own custom .js file. 
+
+=head2 end_html 
+
+	Provides </html>
+
+=head2 head_title
+
+	Provides <title></title>
+	
+	$h->head_title("App/Page Title");
+
+=head2 head_meta
+
+	Provides <meta ... >. Includes the following by default:
+		IE=Edge
+		HandheldFriendly
+		viewport
+	
+	$h->head_meta();
+	
+	Just like body_js_css, you can use both to add default values and your own meta 
+
+=head2 body_topnavbar
+
+	Provides top nav bar optionally.
+	
+	By default it is loaded from secure.bislinks.com which probably be removed in a future version.
+	So, get a copy from bootstrap 3 and store it on your server.
+
+=head2 head_js_css
+
+	provides the ability to add/include .js/.css files in the </head> tag.
+	
+	$h->head_js_css();
+	
+		Default includes the following:
+		
+			bootstrap 3.3.0 .css from maxcdn 
+			navbar-fixed-top.css from secure.bislinks.com
+			jquery 1.12.1 smoothness theme from code.jquery.com 
+			Shim and Respond.js from maxcdn 
+	
+	$h->head_js_css("/path/to/.js")
+	$h->head_js_css("/path/to/.css")
+
+=head2 end_head
+
+	Provides </head>
+	
+	$h->end_head();
+
+=head2 begin_body
+
+	provides <body> tag.
+	
+	$h->begin_body();
+
+=head2 body_accordion
 
-	my $h = Template->new();
 	say $h->body_accordion( $h->open_file("C:/Users/user/public/app/open_file_example.txt", 'Type', 'Header') ); 
 
+=head2 body_article
+
+	provides the ability to add content into <main> tags. 
+	
+	$h->body_article( header => "", content => "");
+
+=head2 end_body
+
+	provides </body> tag.
+	
+	$h->end_body();
+
+=head2 body_form
+
+	provides the ability to add forms 
+	
+	$h->body_form();
+
+=head2 defaults_begin
+
+	Provides defaults for very lightweight template for those in a hurry; Can be used for apps/sites that are under construction! 
+	
+	$h->defaults_begin();
+
+=head2 defaults_end
+
+	provides defaults for lightweight or under construction app/website. 
+	
+	$h->defaults_end();
+
+=head1 HTML Hash
+
+	Default HTML used in default_*
+
+=head2 html_bootstrap_css 
+
 =head1 AUTHOR
 
 Sudheer Murthy, C<< <pause at a1z.us> >>
